from roadmapper.roadmap import Roadmap
from roadmapper.timelinemode import TimelineMode

# Docs: https://github.com/csgoh/roadmapper
YEAR = "2025"

# roadmap top-level config
roadmap = Roadmap(1200, 800)
roadmap.set_title("CLV Roadmap")
# roadmap.set_subtitle("FEEDBACK REQUESTED")
roadmap.set_timeline(TimelineMode.QUARTERLY, start=f"{YEAR}-01-01", number_of_items=4)
roadmap.add_logo("./docs/source/_static/marketing-logo-light.jpg", "top-left", 172, 125)

doc_color = "#70AD47"  # green
model_color = "#4472C4"  # navy blue
util_color = "#ED7D31"  # orange

# Create roadmap swimlanes
group_model = roadmap.add_group("Model Development", fill_colour=model_color)
group_doc = roadmap.add_group(
    "Documentation and Notebooks", fill_colour=doc_color, font_colour="black"
)
group_util = roadmap.add_group(
    "Utilities, Plotting, Maintenance", fill_colour=util_color, font_colour="black"
)

# add tasks and milestones to modeling swimlane
tasks_model = group_model.add_task(
    "Covariate Subscription Model",
    f"{YEAR}-01-01",
    f"{YEAR}-03-31",
    fill_colour=model_color,
    font_colour="white",
)

# new release milestones are assigned to specific tasks
# just add to the task at the top of the roadmap
tasks_model.add_milestone("v0.11.0", f"{YEAR}-01-31")

tasks_model.add_parallel_task(
    "Spend Model w/ Covariates",
    f"{YEAR}-07-01",
    f"{YEAR}-09-30",
    fill_colour=model_color,
    font_colour="white",
)
tasks_model.add_parallel_task(
    "Retail Model Seasonality",
    f"{YEAR}-10-01",
    f"{YEAR}-12-31",
    fill_colour=model_color,
    font_colour="white",
)

# add tasks to documentation swimlane
task_docs = group_doc.add_task(
    "Subscription Model Notebook",
    f"{YEAR}-01-01",
    f"{YEAR}-03-31",
    fill_colour=doc_color,
    font_colour="black",
)
task_docs.add_parallel_task(
    "RFM Segment and BG/BB Notebooks",
    f"{YEAR}-04-01",
    f"{YEAR}-06-30",
    fill_colour=doc_color,
    font_colour="black",
)
task_docs.add_parallel_task(
    "Spend Notebook",
    f"{YEAR}-08-15",
    f"{YEAR}-09-30",
    fill_colour=doc_color,
    font_colour="black",
)

# add tasks to utilities swimlane
task_util = group_util.add_task(
    "Ongoing Maintenance",
    f"{YEAR}-01-01",
    f"{YEAR}-12-31",
    fill_colour=util_color,
    font_colour="black",
)

roadmap.set_footer("Generated by Roadmapper")
roadmap.draw()
roadmap.save("./docs/source/_static/clv_roadmap_2025.png")
